var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import * as signalR from "@microsoft/signalr";
import { nameof } from "ts-simple-nameof";
import { ConnectionResult, AuthorizationInfo, ConnectionState } from "./IExalusConnector";
import { TypedEvent } from "../TypedEvent";
import { Api } from '../Api';
import { LoggerService } from "./Logging/LoggerService";
import { Event } from "../Event";
var ExalusConnectionService = (function () {
    function ExalusConnectionService() {
        this._defaultPacketsBrokerAddress = "br1.tr7.pl";
        this._serversBrokerAddress = "https://broker.tr7.pl";
        this._address = "br1.tr7.pl";
        this._isEstabilished = false;
        this._timeout = 5000;
        this._dataReceivedEvent = new TypedEvent();
        this._pongReceivedEvent = new Event();
        this._authorizationReceivedEvent = new TypedEvent();
        this._registrationReceivedEvent = new TypedEvent();
        this._connectionStateChangedEvent = new TypedEvent();
        this._errorOccuredEvent = new TypedEvent();
        this._log = Api.Get(LoggerService);
    }
    ExalusConnectionService.prototype.InitializeConnection = function () {
        this._log.Debug(ExalusConnectionService, "Initializing Exalus Cloud connection service");
        if (this._connection)
            throw new Error("Connection already initialized");
        if (!this._address)
            throw new Error("Domain is not set");
        if (!this._serialId)
            throw new Error("SerialId is not set");
        if (!this._PIN)
            throw new Error("PIN is not set");
        this._connection = new signalR.HubConnectionBuilder()
            .withUrl("https://".concat(this._address, "/broker"))
            .build();
    };
    ExalusConnectionService.prototype.GetServiceName = function () {
        return nameof(ExalusConnectionService);
    };
    ExalusConnectionService.prototype.SetServersBrokerAddress = function (address) {
        this._serversBrokerAddress = address;
    };
    ExalusConnectionService.prototype.SetDefaultPacketsBrokerAddress = function (address) {
        this._defaultPacketsBrokerAddress = address;
        this._address = address;
    };
    ExalusConnectionService.prototype.GetServerAddressAsync = function () {
        return __awaiter(this, void 0, void 0, function () {
            var result, address, ex_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 5, , 6]);
                        return [4, fetch("".concat(this._serversBrokerAddress, "/api/connections/broker/whichserver/").concat(this._serialId))];
                    case 1:
                        result = _a.sent();
                        if (!result.ok) return [3, 3];
                        return [4, result.text()];
                    case 2:
                        address = _a.sent();
                        this._log.Debug(ExalusConnectionService, "Got server address: ".concat(address));
                        return [2, address];
                    case 3:
                        this._log.Error(ExalusConnectionService, "Failed to get server address, status: ".concat(result.status));
                        return [2, null];
                    case 4: return [3, 6];
                    case 5:
                        ex_1 = _a.sent();
                        this._log.Error(ExalusConnectionService, ex_1);
                        return [2, null];
                    case 6: return [2];
                }
            });
        });
    };
    ExalusConnectionService.prototype.ConnectAsync = function (address) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this._address = address;
                        return [4, this.connectAsync()];
                    case 1: return [2, _a.sent()];
                }
            });
        });
    };
    ExalusConnectionService.prototype.AuthorizeAsync = function (authorizationInfo) {
        var _this = this;
        var timeoutTime = 2000;
        return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
            var timeoutId, sub, onTimeout;
            var _this = this;
            var _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        timeoutId = 0;
                        sub = function (result) {
                            window.clearTimeout(timeoutId);
                            _this._authorizationReceivedEvent.Unsubscribe(sub);
                            resolve(result);
                        };
                        onTimeout = function () {
                            window.clearTimeout(timeoutId);
                            _this._authorizationReceivedEvent.Unsubscribe(sub);
                            resolve(false);
                        };
                        timeoutId = window.setTimeout(onTimeout, timeoutTime);
                        this._authorizationReceivedEvent.Subscribe(sub);
                        return [4, ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.send("AuthorizeTo", authorizationInfo.SerialNumber, authorizationInfo.PIN))];
                    case 1:
                        _b.sent();
                        return [2];
                }
            });
        }); });
    };
    ExalusConnectionService.prototype.ConnectAndAuthorizeAsync = function (authorizationInfo) {
        return __awaiter(this, void 0, void 0, function () {
            var packetsBroker, conResult;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (this._isEstabilished)
                            return [2, Promise.resolve(ConnectionResult.Connected)];
                        this._isEstabilished = true;
                        this._serialId = authorizationInfo.SerialNumber;
                        this._PIN = authorizationInfo.PIN;
                        return [4, this.GetServerAddressAsync()];
                    case 1:
                        packetsBroker = _a.sent();
                        if (packetsBroker == null)
                            return [2, Promise.resolve(ConnectionResult.FailedToConnectToServer)];
                        this._address = packetsBroker;
                        return [4, this.connectAsync()];
                    case 2:
                        conResult = _a.sent();
                        if (conResult != ConnectionResult.Connected)
                            return [2, conResult];
                        return [4, this.AuthorizeAsync(authorizationInfo)];
                    case 3: return [2, (_a.sent())
                            ? ConnectionResult.Connected : ConnectionResult.AuthorizationFailed];
                }
            });
        });
    };
    ExalusConnectionService.prototype.connectAsync = function () {
        var _a, _b, _c, _d, _e, _f, _g;
        return __awaiter(this, void 0, void 0, function () {
            var dataReceivedEvent, connectionEvent;
            var _this = this;
            return __generator(this, function (_h) {
                switch (_h.label) {
                    case 0:
                        this.InitializeConnection();
                        return [4, ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.start())];
                    case 1:
                        _h.sent();
                        (_b = this._connection) === null || _b === void 0 ? void 0 : _b.on("Pong", function () {
                            _this._log.Debug(ExalusConnectionService, "Pong received <-");
                            _this._pongReceivedEvent.Invoke();
                        });
                        (_c = this._connection) === null || _c === void 0 ? void 0 : _c.on("Registration", function (data) {
                            var _a;
                            (_a = _this._registrationReceivedEvent) === null || _a === void 0 ? void 0 : _a.Invoke(data);
                        });
                        (_d = this._connection) === null || _d === void 0 ? void 0 : _d.on("Authorization", function (data) {
                            var _a;
                            _this._log.Debug(ExalusConnectionService, "Received authorization response: ".concat(data));
                            (_a = _this._authorizationReceivedEvent) === null || _a === void 0 ? void 0 : _a.Invoke(data);
                        });
                        (_e = this._connection) === null || _e === void 0 ? void 0 : _e.on("SendError", function (sender, data) { return __awaiter(_this, void 0, void 0, function () {
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        if (!sender.startsWith("NotAuthorized:")) return [3, 2];
                                        this._log.Warning(ExalusConnectionService, "Failed to authorize!");
                                        return [4, this.AuthorizeAsync(new AuthorizationInfo(this._serialId, this._PIN))];
                                    case 1:
                                        _a.sent();
                                        return [3, 3];
                                    case 2:
                                        this._log.Error(ExalusConnectionService, "Server returned error: ".concat(sender, " ").concat(data));
                                        this._errorOccuredEvent.Invoke([sender, data]);
                                        _a.label = 3;
                                    case 3: return [2];
                                }
                            });
                        }); });
                        dataReceivedEvent = this._dataReceivedEvent;
                        (_f = this._connection) === null || _f === void 0 ? void 0 : _f.on("Data", function (sender, data) {
                            var d = JSON.parse(data);
                            _this._log.Debug(ExalusConnectionService, "Received data:\n".concat(JSON.stringify(d, null, 2)));
                            dataReceivedEvent.Invoke(d);
                        });
                        connectionEvent = this._connectionStateChangedEvent;
                        switch ((_g = this._connection) === null || _g === void 0 ? void 0 : _g.state) {
                            case signalR.HubConnectionState.Connected:
                                connectionEvent.Invoke(ConnectionState.Connected);
                                return [2, ConnectionResult.Connected];
                            case signalR.HubConnectionState.Connecting:
                                connectionEvent.Invoke(ConnectionState.Connecting);
                                return [2, ConnectionResult.Connected];
                            case signalR.HubConnectionState.Disconnected:
                                connectionEvent.Invoke(ConnectionState.Disconnected);
                                return [2, ConnectionResult.FailedToConnect];
                            case signalR.HubConnectionState.Disconnecting:
                                connectionEvent.Invoke(ConnectionState.Disconnecting);
                                return [2, ConnectionResult.FailedToConnect];
                            case signalR.HubConnectionState.Reconnecting:
                                connectionEvent.Invoke(ConnectionState.Reconnecting);
                                return [2, ConnectionResult.FailedToConnect];
                        }
                        return [2, ConnectionResult.FailedToConnect];
                }
            });
        });
    };
    ExalusConnectionService.prototype.DisconnectAsync = function () {
        var _a;
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4, ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.stop())];
                    case 1:
                        _b.sent();
                        return [2];
                }
            });
        });
    };
    ExalusConnectionService.prototype.IsConnected = function () {
        var _a;
        return ((_a = this._connection) === null || _a === void 0 ? void 0 : _a.state) === signalR.HubConnectionState.Connected;
    };
    ExalusConnectionService.prototype.SendAndWaitForResponseAsync = function (dataFrame, timeout, useCache, logTransmission) {
        var _this = this;
        if (logTransmission === void 0) { logTransmission = false; }
        var timeoutId = 0;
        var time = new Date();
        var startTime = time.getDate();
        if (!this.IsConnected())
            throw new Error("Connection is not established");
        return new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
            var onReceivedFrame, errorMessage;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        onReceivedFrame = function (receivedFrame) {
                            if ((receivedFrame === null || receivedFrame === void 0 ? void 0 : receivedFrame.TransactionId) == dataFrame.TransactionId) {
                                window.clearTimeout(timeoutId);
                                _this._dataReceivedEvent.Unsubscribe(onReceivedFrame);
                                var difference = startTime - time.getDate();
                                if (logTransmission)
                                    _this._log.Debug(ExalusConnectionService, "Received response for: ".concat(receivedFrame === null || receivedFrame === void 0 ? void 0 : receivedFrame.Resource, " ").concat(receivedFrame === null || receivedFrame === void 0 ? void 0 : receivedFrame.Method, " id: ").concat(receivedFrame === null || receivedFrame === void 0 ? void 0 : receivedFrame.TransactionId, " in ").concat(difference, "ms"));
                                resolve(receivedFrame);
                            }
                        };
                        this._dataReceivedEvent.Subscribe(onReceivedFrame);
                        return [4, this.SendAsync(dataFrame, logTransmission)];
                    case 1:
                        if (!(_a.sent())) {
                            errorMessage = "Failed to send request, resource: ".concat(dataFrame.Resource, " method: ").concat(dataFrame.Method, " transaction id: ").concat(dataFrame.TransactionId);
                            reject(new Error(errorMessage));
                        }
                        else
                            timeoutId = window.setTimeout(function () {
                                _this._dataReceivedEvent.Unsubscribe(onReceivedFrame);
                                var errorMessage = "Response timeout, resource: ".concat(dataFrame.Resource, " method: ").concat(dataFrame.Method, " transaction id: ").concat(dataFrame.TransactionId);
                                _this._log.Error(ExalusConnectionService, errorMessage);
                                reject(new signalR.TimeoutError(errorMessage));
                            }, timeout);
                        return [2];
                }
            });
        }); });
    };
    ExalusConnectionService.prototype.SendAsync = function (dataFrame, logTransmission) {
        var _this = this;
        if (logTransmission === void 0) { logTransmission = false; }
        if (!this.IsConnected())
            throw new Error("Connection is not established");
        return new Promise(function (resolve) {
            var _a;
            if (logTransmission)
                _this._log.Debug(ExalusConnectionService, "Send DataFrame ".concat(dataFrame.Resource, " ").concat(dataFrame.Method, " transaction id: ").concat(dataFrame.TransactionId, " "));
            (_a = _this._connection) === null || _a === void 0 ? void 0 : _a.invoke("SendTo", _this._serialId, dataFrame).then(function () {
                resolve(true);
            }).catch(function (err) {
                _this._log.Error(ExalusConnectionService, err);
                resolve(false);
            });
        });
    };
    ExalusConnectionService.prototype.OnDataReceivedEvent = function () {
        return this._dataReceivedEvent;
    };
    ExalusConnectionService.prototype.OnConnectionStateChangedEvent = function () {
        return this._connectionStateChangedEvent;
    };
    ExalusConnectionService.prototype.OnErrorOccuredEvent = function () {
        return this._errorOccuredEvent;
    };
    return ExalusConnectionService;
}());
export { ExalusConnectionService };
//# sourceMappingURL=ExalusConnectionService.js.map